@@ -9,7 +9,9 @@ for d3.js without taking away the power that d3.js gives you.
 Project location : https://github.com/areski/python-nvd3
 """
 
-from .NVD3Chart import NVD3Chart, stab
+from .NVD3Chart import NVD3Chart
+from jinja2 import DebugUndefined, Environment, FileSystemLoader, Template
+import os
 
 
 class pieChart(NVD3Chart):
@@ -75,6 +77,13 @@ class pieChart(NVD3Chart):
           return chart;
         });
     """
+
+    CHART_FILENAME = "./pie.html"
+
+    template_environment = Environment(lstrip_blocks = True, trim_blocks = True)
+    template_environment.loader = FileSystemLoader(os.path.join(os.path.dirname(__file__), 'templates'))
+    template_chart_nvd3 = template_environment.get_template(CHART_FILENAME) 
+
     def __init__(self, **kwargs):
         NVD3Chart.__init__(self, **kwargs)
         height = kwargs.get('height', 450)
@@ -90,36 +99,4 @@ class pieChart(NVD3Chart):
 
     def buildjschart(self):
         NVD3Chart.buildjschart(self)
-
-        color_js = ''
-        if self.color_list:
-            color_js += "var mycolor = new Array();\n"
-            color_count = 0
-            for i in self.color_list:
-                color_js += stab(2) + "mycolor[" + str(color_count) + "] = '" + i + "';\n"
-                color_count = int(color_count) + 1
-
-        # add mycolor var in js before nv.addGraph starts
-        if self.color_list:
-            start_js = self.jschart.find('nv.addGraph')
-            #start_js_len = len('nv.addGraph')
-            replace_index = start_js
-            if start_js > 0:
-                self.jschart = self.jschart[:replace_index] + color_js + self.jschart[replace_index:]
-
-        pie_jschart = '\n' + stab(2) + 'chart.x(function(d) { return d.label })\n' + \
-            stab(3) + '.y(function(d) { return d.value });\n'
-        if self.width:
-            pie_jschart += stab(2) + 'chart.width(%s);\n' % self.width
-        if self.height:
-            pie_jschart += stab(2) + 'chart.height(%s);\n' % self.height
-
-        # add custom colors for pieChart
-        if self.color_list and color_js:
-            pie_jschart += stab(2) + 'chart.color(mycolor);\n'
-
-        start_index = self.jschart.find('.pieChart();')
-        string_len = len('.pieChart();')
-        replace_index = start_index + string_len
-        if start_index > 0:
-            self.jschart = self.jschart[:replace_index] + pie_jschart + self.jschart[replace_index:]
+        self.jschart = self.template_chart_nvd3.render(chart = self)
